@@ -50,6 +50,7 @@ struct _EphyActionBar {
   GtkWidget *toolbar;
   GtkWidget *menu_button;
   AdwTabButton *tab_button;
+  GtkWidget *bookmarks_button;
   GtkWidget *navigation_back;
   GtkWidget *navigation_forward;
   GCancellable *cancellable;
@@ -557,6 +558,8 @@ ephy_action_bar_dispose (GObject *object)
   g_cancellable_cancel (action_bar->cancellable);
   g_clear_object (&action_bar->cancellable);
 
+  g_clear_handle_id (&action_bar->downloads_button_attention_timeout_id, g_source_remove);
+
   G_OBJECT_CLASS (ephy_action_bar_parent_class)->dispose (object);
 }
 
@@ -588,6 +591,7 @@ ephy_action_bar_class_init (EphyActionBarClass *klass)
   gtk_widget_class_bind_template_child (widget_class, EphyActionBar, tab_button);
   gtk_widget_class_bind_template_child (widget_class, EphyActionBar, navigation_back);
   gtk_widget_class_bind_template_child (widget_class, EphyActionBar, navigation_forward);
+  gtk_widget_class_bind_template_child (widget_class, EphyActionBar, bookmarks_button);
   gtk_widget_class_bind_template_child (widget_class, EphyActionBar, menu_button);
   gtk_widget_class_bind_template_child (widget_class, EphyActionBar, downloads_button);
   gtk_widget_class_bind_template_child (widget_class, EphyActionBar, downloads_icon);
@@ -615,6 +619,8 @@ ephy_action_bar_init (EphyActionBar *action_bar)
   mode = ephy_embed_shell_get_mode (embed_shell);
   gtk_widget_set_visible (GTK_WIDGET (action_bar->tab_button),
                           mode != EPHY_EMBED_SHELL_MODE_APPLICATION);
+  gtk_widget_set_visible (GTK_WIDGET (action_bar->bookmarks_button),
+                          mode != EPHY_EMBED_SHELL_MODE_APPLICATION);
 
   /* Downloads */
   downloads_manager = ephy_embed_shell_get_downloads_manager (embed_shell);
